@@ -6,7 +6,6 @@ from sqlalchemy.dialects.postgresql.base import PGDialect
 from sqlalchemy.dialects.postgresql import INET
 from sqlalchemy.dialects.postgresql import UUID
 from sqlalchemy.ext.compiler import compiles
-from sqlalchemy.util import asbool
 from sqlalchemy.util import warn
 import sqlalchemy.sql as sql
 
@@ -15,7 +14,6 @@ import sqlalchemy.types as sqltypes
 from .stmt_compiler import CockroachCompiler, CockroachIdentifierPreparer
 from .ddl_compiler import CockroachDDLCompiler
 
-import pkg_resources
 
 # Map type names (as returned by information_schema) to sqlalchemy type
 # objects.
@@ -95,12 +93,12 @@ class CockroachDBDialect(PGDialect):
     ddl_compiler = CockroachDDLCompiler
 
     # Override connect so we can take disable_cockroachdb_telemetry as a connect_arg to sqlalchemy.
+    # The option is not used any more, but removing it is a backwards-incompatible change.
     def connect(
         self,
         disable_cockroachdb_telemetry=False,
         **kwargs,
     ):
-        self.disable_cockroachdb_telemetry = asbool(disable_cockroachdb_telemetry)
         return super().connect(**kwargs)
 
     def __init__(self, *args, **kwargs):
@@ -112,11 +110,6 @@ class CockroachDBDialect(PGDialect):
         kwargs["server_side_cursors"] = False
         super().__init__(*args, **kwargs)
 
-    @classmethod
-    def dbapi(cls):
-        # this gets defined at the driver level (e.g. psycopg2)
-        raise NotImplementedError
-
     def initialize(self, connection):
         # Bypass PGDialect's initialize implementation, which looks at
         # server_version_info and performs postgres-specific queries
@@ -140,26 +133,6 @@ class CockroachDBDialect(PGDialect):
         self._supports_savepoints = self._is_v201plus
         self.supports_native_enum = self._is_v202plus
 
-        # Increment third party tool telemetry counter for SQLAlchemy.
-        # The crdb_internal.increment_feature_counter only exists in v21.1 of CRDB
-        # and onwards.
-        if self._is_v211plus and not self.disable_cockroachdb_telemetry:
-            sqlalchemy_version_string = ""
-            dialect_version = pkg_resources.require("sqlalchemy-cockroachdb")[0].version
-            sqlalchemy_version = pkg_resources.require("sqlalchemy")[0].version
-            matches = re.findall(r"(\d+\.\d+)(\.|$)", sqlalchemy_version)
-            if len(matches) == 0:
-                sqlalchemy_version_string = sqlalchemy_version
-            else:
-                sqlalchemy_version_string = matches[0][0]
-            telemetry_query = "SELECT crdb_internal.increment_feature_counter(:val)"
-            connection.execute(
-                text(telemetry_query), dict(val=f"sqlalchemy-cockroachdb {dialect_version}")
-            )
-            connection.execute(
-                text(telemetry_query), dict(val=f"sqlalchemy {sqlalchemy_version_string}")
-            )
-
     def _get_server_version_info(self, conn):
         # PGDialect expects a postgres server version number here,
         # although we've overridden most of the places where it's
@@ -182,10 +155,25 @@ class CockroachDBDialect(PGDialect):
             )
         ]
 
-    def has_table(self, conn, table, schema=None):
+    def has_table(self, conn, table, schema=None, info_cache=None):
         # Upstream implementation needs pg_table_is_visible().
         return any(t == table for t in self.get_table_names(conn, schema=schema))
 
+    def get_multi_columns(
+        self, connection, schema, filter_names, scope, kind, **kw
+    ):
+        """
+        PGDialect in SQLA 2.0 uses get_multi_columns() when reflecting a table
+        using Table(…, autoload_with=engine), so we'll just return the values
+        for the first table in the filter_names list for now (since there
+        should only be just one).
+        """
+        if not filter_names or not isinstance(filter_names, list) or len(filter_names) > 1:
+            raise ValueError("filter_names must be a single-value list (for now)")
+        table_name = filter_names[0]
+        col_info = self.get_columns(connection, table_name, schema, **kw)
+        return {(schema, table_name): col_info}
+
     # The upstream implementations of the reflection functions below depend on
     # correlated subqueries which are not yet supported.
     def get_columns(self, conn, table_name, schema=None, **kw):
