@@ -1,11 +1,11 @@
 from sqlalchemy.dialects.postgresql.psycopg2 import PGDialect_psycopg2
-from .base import CockroachDBDialect
+from ._psycopg_common import _CockroachDBDialect_common_psycopg
 from .ddl_compiler import CockroachDDLCompiler
 from .stmt_compiler import CockroachCompiler
 from .stmt_compiler import CockroachIdentifierPreparer
 
 
-class CockroachDBDialect_psycopg2(PGDialect_psycopg2, CockroachDBDialect):
+class CockroachDBDialect_psycopg2(_CockroachDBDialect_common_psycopg, PGDialect_psycopg2):
     driver = "psycopg2"  # driver name
     preparer = CockroachIdentifierPreparer
     ddl_compiler = CockroachDDLCompiler
